ThreeJS class

Constructors

ThreeJS(WxGLContext context, int width, int height, void onSetupComplete(), {Settings? mySettings})

Properties

camera ↔ PerspectiveCamera
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height → int
no setter
onSetupComplete ↔ void Function()
getter/setter pair
renderer ↔ AngleRenderer
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scene ↔ Scene
getter/setter pair
settings ↔ Settings
latefinal
width → int
no setter

Methods

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setSize(int width, int height) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited