SingleUniform class

Mixed-in types

Constructors

SingleUniform(dynamic id, WxGlActiveInfo activeInfo, WxGlUniformLocation addr)

Properties

activeInfo ↔ WxGlActiveInfo
getter/setter pair
addr ↔ WxGlUniformLocation
getter/setter pairinherited
cache Map<int, dynamic>
getter/setter pairinherited
flat Float32List
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
id ↔ dynamic
getter/setter pairinherited
iv Int32List
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
setValue Function
getter/setter pair
size int
getter/setter pairinherited
type int
getter/setter pair

Methods

allocTexUnits(dynamic textures, dynamic n) Int32List
inherited
arraysEqual(Map<int, dynamic> a, dynamic b) bool
inherited
copyArray(Map<int, dynamic> a, dynamic b) → void
inherited
dispose() → void
inherited
flatten(List? array, int nBlocks, int blockSize) Float32List
inherited
getPureArraySetter(int type) → dynamic
inherited
getSingularSetter(int type) Function
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setValueM2(WxGLContext gl, dynamic v, [AngleTextures? textures]) → void
inherited
setValueM2Array(WxGLContext gl, dynamic v, [AngleTextures? textures]) → void
inherited
setValueM3(WxGLContext gl, Matrix3? v, [AngleTextures? textures]) → void
inherited
setValueM3Array(WxGLContext gl, dynamic v, [AngleTextures? textures]) → void
inherited
setValueM4(WxGLContext gl, Matrix4 v, [AngleTextures? textures]) → void
inherited
setValueM4Array(WxGLContext gl, dynamic v, [AngleTextures? textures]) → void
inherited
setValueT1(WxGLContext gl, Texture? v, AngleTextures textures) → void
inherited
setValueT1Array(WxGLContext gl, dynamic v, [AngleTextures? textures]) → void
inherited
setValueT2DArray1(WxGLContext gl, Texture? v, AngleTextures textures) → void
inherited
setValueT2DArrayArray(WxGLContext gl, dynamic v, [AngleTextures? textures]) → void
inherited
setValueT3D1(WxGLContext gl, Texture? v, [AngleTextures? textures]) → void
inherited
setValueT3DArray(WxGLContext gl, dynamic v, [AngleTextures? textures]) → void
inherited
setValueT6(WxGLContext gl, Texture? v, [AngleTextures? textures]) → void
inherited
setValueT6Array(WxGLContext gl, dynamic v, [AngleTextures? textures]) → void
inherited
setValueV1f(WxGLContext gl, dynamic v, [AngleTextures? textures]) → void
inherited
setValueV1fArray(WxGLContext gl, dynamic v, [AngleTextures? textures]) → void
inherited
setValueV1i(WxGLContext gl, dynamic v, [AngleTextures? textures]) → void
inherited
setValueV1iArray(WxGLContext gl, dynamic v, [AngleTextures? textures]) → void
inherited
setValueV1ui(WxGLContext gl, dynamic v, [AngleTextures? textures]) → void
inherited
setValueV1uiArray(WxGLContext gl, dynamic v, [AngleTextures? textures]) → void
inherited
setValueV2f(WxGLContext gl, dynamic v, [AngleTextures? textures]) → void
inherited
setValueV2fArray(WxGLContext gl, dynamic v, [AngleTextures? textures]) → void
inherited
setValueV2i(WxGLContext gl, Vector v, [AngleTextures? textures]) → void
inherited
setValueV2iArray(WxGLContext gl, dynamic v, [AngleTextures? textures]) → void
inherited
setValueV2ui(WxGLContext gl, dynamic v, [AngleTextures? textures]) → void
inherited
setValueV2uiArray(WxGLContext gl, dynamic v, [AngleTextures? textures]) → void
inherited
setValueV3f(WxGLContext gl, dynamic v, [AngleTextures? textures]) → void
inherited
setValueV3fArray(WxGLContext gl, dynamic v, [AngleTextures? textures]) → void
inherited
setValueV3i(WxGLContext gl, dynamic v, [AngleTextures? textures]) → void
inherited
setValueV3iArray(WxGLContext gl, dynamic v, [AngleTextures? textures]) → void
inherited
setValueV3ui(WxGLContext gl, dynamic v, [AngleTextures? textures]) → void
inherited
setValueV3uiArray(WxGLContext gl, dynamic v, [AngleTextures? textures]) → void
inherited
setValueV4f(WxGLContext gl, dynamic v, [AngleTextures? textures]) → void
inherited
setValueV4fArray(WxGLContext gl, dynamic v, [AngleTextures? textures]) → void
inherited
setValueV4i(WxGLContext gl, dynamic v, [AngleTextures? textures]) → void
inherited
setValueV4iArray(WxGLContext gl, dynamic v, [AngleTextures? textures]) → void
inherited
setValueV4ui(WxGLContext gl, dynamic v, [AngleTextures? textures]) → void
inherited
setValueV4uiArray(WxGLContext gl, dynamic v, [AngleTextures? textures]) → void
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited